---
title: "Achiving PCA"
output: html_document
---

## Before start

In our R session, we will need to
- define the working directory: setwd("/home/Earth/nperez/MEDSCOPE/AemetEida/STEP1")
- install and load R packages

```r
library(s2dverification)
```


## Workflow of aemetEida branch in CSTools

The first step is to define the region in which NAO will be computed. Currently, there is a file called `id_sectors.dic` with code, long and short names and maximum and minimum latitudes for 10 different regions and one function called `ReadSectorCoord` to read the coordinates and build two vectors for lon and lat.

I will try to merge this info in a single function. The output should be useful for a Load or Start call. 
Doubt: are these sectors a international codification used by the scientific comunity?


```r
SelectSector <- function(code = NULL, shortName = NULL, longName = NULL, graphicName = NULL) {
  if (is.null(c(code, shortName, longName, graphicName))) {
    stop("One of the parameters must be specified.")
  }
  if (code == "AE1.00" || shortName == "AESector1.00" || graphicName == "Atlantic/European1.00" ||longName == "Atlantic/European1.00") {
    latmax = 85.0
    latmin = 25.0
    reslat = -1.00
    lonmin = -80.0
    lonmax = 40.0
    reslon = 1.00
   }
  return(list(lonmin = lonmin, lonmax = lonmax, latmin = latmin, latmax = latmax))
}
```

```r
coord <- SelectSector("AE1.00")
```


The output is:


```r
> SelectSector(code = "AE1.00")
$lonmin
[1] -80

$lonmax
[1] 40

$latmin
[1] 25

$latmax
[1] 85
```


The user should select the season and the years of observation. The years are a string and the season a numeric vector in the fijarParametros_exp01.R configuration file. So, we can do it here in the same way:


```r 
seasonPCA <- c(12, 1, 2, 3) # meses para hacer el analisis PCA
arrayAnnosPCA <- 1993: 2016  # annos para hacer el analisis PCA
```


Then the `GetObsmm` function is used to read the data for the coordinates and the dates previously defined, and the geopotential at 500 hPa saved in the path "AemetEida/STEP1/DATOS_PROYECTO/MEDSCOPE/MEDSCOPE_v2.0/FicherosDatos/Reanalisis/z500_GLOBAL0_1.00deg_ei_mm.nc"
This file is preprocessed data with Script: $HOME/proyectos/MEDSCOPE/z500mm_ei.ksh

The parameters `leadtimemin` and `leadtimemax` have been defined taken into account that the origin of the data contained in the file .nc is year 1975 and the resolution of the data is monthly. So, if the period 1993-2017 has been selected, the parameters could be calculated as 
  leadtimemin = (1993 - 1975) * 12 + 1
  leadtimemax = (2017 - 1975 + 1) * 12
  

```
reanal <- list(name = "erainterim", path = "./DATOS_PROYECTO/MEDSCOPE/MEDSCOPE_v2.0/FicherosDatos/Reanalisis/$VAR_NAME$500_GLOBAL0_1.00deg_ei_mm.nc")

data <- Load(var = "z", obs = list(reanal), sdates = c('19750101'), output = 'lonlat', storefreq = 'monthly', lonmin = coord$lonmin, lonmax = coord$lonmax, latmin = coord$latmin, latmax = coord$latmax, leadtimemin = 217, leadtimemax = 518)
```

The content of the `data` can be reviewed visualizing the strecture:


```r
> str(data$exp)
 NULL
> str(data$obs)
 num [1, 1, 1, 1:288, 1:61, 1:121] 48024 49024 48852 50448 52726 ...
 - attr(*, "dimensions")= chr [1:6] "dataset" "member" "sdate" "ftime" ...
> str(data$Dates$start)
 POSIXct[1:288], format: "1993-01-01" "1993-02-01" "1993-03-01" "1993-04-01" "1993-05-01" "1993-06-01" "1993-07-01" ...
```

A season selection is performed for the long winter definition from December to March.

So, we can create a `SelectSeason` function to be applied on s2dverification data format or the next functions can be prepare to give that option.

dim(data$obs)

            nt <- 4
            anomVar <- array(dim = dim(data$obs))
            # Generating anomalies without cross-validation technique
clim <- Apply(data$obs, target_dims = list(c('ftime')), fun = mean, na.rm = TRUE)
anom <- Apply(data$obs, target_dims = list(c('ftime')), fun = function(x){x - clim$output1})             
             

## Including Plots

You can also embed plots, for example:

```{r pressure, echo=FALSE}
plot(pressure)
```

Note that the `echo = FALSE` parameter was added to the code chunk to prevent printing of the R code that generated the plot.
